@@ -7,7 +7,7 @@ use warnings;
 
 # VERSION
 
-our $VERSION = '1.23';
+our $VERSION = '1.30';
 
 # AUTHORITY
 
@@ -22,6 +22,16 @@ sub import {
 
   no strict 'refs';
 
+  my %exports = (
+    catch => 1,
+    error => 1,
+    false => 1,
+    raise => 1,
+    true => 1,
+  );
+
+  @args = grep defined && !ref && /^[A-Za-z]/ && $exports{$_}, @args;
+
   my %seen;
   for my $name (grep !$seen{$_}++, @args, 'true', 'false') {
     *{"${target}::${name}"} = $self->can($name) if !$target->can($name);
@@ -56,9 +66,9 @@ sub error (;$) {
 }
 
 sub false () {
-  require Venus::Boolean;
+  require Venus::False;
 
-  return Venus::Boolean::FALSE();
+  return Venus::False->value;
 }
 
 sub raise ($;$) {
@@ -77,9 +87,9 @@ sub raise ($;$) {
 }
 
 sub true () {
-  require Venus::Boolean;
+  require Venus::True;
 
-  return Venus::Boolean::TRUE();
+  return Venus::True->value;
 }
 
 1;
@@ -99,7 +109,7 @@ OO Standard Library for Perl 5
 
 =head1 VERSION
 
-1.23
+1.30
 
 =cut
 
@@ -915,4 +925,11 @@ B<example 1>
 
 Awncorp, C<awncorp@cpan.org>
 
+=head1 LICENSE
+
+Copyright (C) 2000, Al Newkirk.
+
+This program is free software, you can redistribute it and/or modify it under
+the terms of the Apache license version 2.0.
+
 =cut
\ No newline at end of file
