@@ -17,6 +17,18 @@ use overload (
 
 # METHODS
 
+sub assertion {
+  my ($self) = @_;
+
+  my $assert = $self->SUPER::assertion;
+
+  $assert->constraints->clear;
+
+  $assert->constraint('scalar', true);
+
+  return $assert;
+}
+
 sub default {
   return \'';
 }
