@@ -15,6 +15,35 @@ with 'Venus::Role::Accessible';
 
 use Scalar::Util ();
 
+# BUILDERS
+
+sub build_arg {
+  my ($self, $data) = @_;
+
+  return {
+    value => $data
+  };
+}
+
+sub build_args {
+  my ($self, $data) = @_;
+
+  if (keys %$data == 1 && exists $data->{value}) {
+    return $data;
+  }
+  return {
+    value => $self->default
+  };
+}
+
+sub build_nil {
+  my ($self, $data) = @_;
+
+  return {
+    value => $data
+  };
+}
+
 # METHODS
 
 sub cast {
@@ -38,20 +67,13 @@ sub cast {
 sub code {
   my ($self) = @_;
 
-  my $package = $self->package;
+  return scalar $self->identify;
+}
 
-  return "ARRAY" if $package eq "Venus::Array";
-  return "BOOLEAN" if $package eq "Venus::Boolean";
-  return "HASH" if $package eq "Venus::Hash";
-  return "CODE" if $package eq "Venus::Code";
-  return "FLOAT" if $package eq "Venus::Float";
-  return "NUMBER" if $package eq "Venus::Number";
-  return "STRING" if $package eq "Venus::String";
-  return "SCALAR" if $package eq "Venus::Scalar";
-  return "REGEXP" if $package eq "Venus::Regexp";
-  return "UNDEF" if $package eq "Venus::Undef";
+sub coded {
+  my ($self, $code) = @_;
 
-  return undef;
+  return uc($self->code) eq uc("$code");
 }
 
 sub deduce {
@@ -153,6 +175,11 @@ sub deduce_stringlike {
   return $self->into_string;
 }
 
+sub default {
+
+  return undef;
+}
+
 sub detract {
   my ($self) = @_;
 
@@ -796,6 +823,54 @@ sub from_undef_to_undef {
   return $self->into_undef($data);
 }
 
+sub identify {
+  my ($self) = @_;
+
+  my $data = $self->get;
+
+  my $defined = true;
+  my $blessed = false;
+
+  my $type_name;
+
+  if (not(defined($data))) {
+    $type_name = 'UNDEF';
+    $defined = false;
+  }
+  elsif (scalar_is_blessed($data)) {
+    $type_name = $data->isa('Regexp') ? 'REGEXP' : 'OBJECT';
+    $blessed = true;
+  }
+  elsif (ref($data)) {
+    if (ref($data) eq 'ARRAY') {
+      $type_name = 'ARRAY';
+    }
+    elsif (ref($data) eq 'CODE') {
+      $type_name = 'CODE';
+    }
+    elsif (ref($data) eq 'HASH') {
+      $type_name = 'HASH';
+    }
+    else {
+      $type_name = 'SCALAR';
+    }
+  }
+  elsif (scalar_is_boolean($data)) {
+    $type_name = 'BOOLEAN';
+  }
+  elsif (scalar_is_float($data)) {
+    $type_name = 'FLOAT';
+  }
+  elsif (scalar_is_numeric($data)) {
+    $type_name = 'NUMBER';
+  }
+  else {
+    $type_name = 'STRING';
+  }
+
+  return wantarray ? ($defined, $blessed, $type_name) : $type_name;
+}
+
 sub into_array {
   my ($self, $data) = @_;
 
@@ -1052,6 +1127,41 @@ I<Since C<0.01>>
 
 =cut
 
+=head2 coded
+
+  coded(Str $code) (Bool)
+
+The coded method return true or false if the data type name provided matches
+the result of L</code>.
+
+I<Since C<1.23>>
+
+=over 4
+
+=item coded example 1
+
+  # given: synopsis;
+
+  my $coded = $type->coded('ARRAY');
+
+  # 1
+
+=back
+
+=over 4
+
+=item coded example 2
+
+  # given: synopsis;
+
+  my $coded = $type->coded('HASH');
+
+  # 0
+
+=back
+
+=cut
+
 =head2 deduce
 
   deduce() (Object)
@@ -1300,6 +1410,81 @@ I<Since C<0.01>>
 
 =cut
 
+=head2 identify
+
+  identify() (Bool, Bool, Str)
+
+The identify method returns the value's data type, or L</code>, in scalar
+context. In list context, this method will return a tuple with (defined,
+blessed, and data type) elements. B<Note:> For globs and file handles this
+method will return "scalar" as the data type.
+
+I<Since C<1.23>>
+
+=over 4
+
+=item identify example 1
+
+  # given: synopsis
+
+  package main;
+
+  my ($defined, $blessed, $typename) = $type->identify;
+
+  # (1, 0, 'ARRAY')
+
+=back
+
+=over 4
+
+=item identify example 2
+
+  package main;
+
+  use Venus::Type;
+
+  my $type = Venus::Type->new(value => {});
+
+  my ($defined, $blessed, $typename) = $type->identify;
+
+  # (1, 0, 'HASH')
+
+=back
+
+=over 4
+
+=item identify example 3
+
+  package main;
+
+  use Venus::Type;
+
+  my $type = Venus::Type->new(value => qr//);
+
+  my ($defined, $blessed, $typename) = $type->identify;
+
+  # (1, 1, 'REGEXP')
+
+=back
+
+=over 4
+
+=item identify example 4
+
+  package main;
+
+  use Venus::Type;
+
+  my $type = Venus::Type->new(value => bless{});
+
+  my ($defined, $blessed, $typename) = $type->identify;
+
+  # (1, 1, 'OBJECT')
+
+=back
+
+=cut
+
 =head2 package
 
   package() (Str)
