@@ -41,6 +41,18 @@ sub build_self {
 
 # METHODS
 
+sub assertion {
+  my ($self) = @_;
+
+  my $assert = $self->SUPER::assertion;
+
+  $assert->constraints->clear;
+
+  $assert->constraint('hash', true);
+
+  return $assert;
+}
+
 sub default {
   my ($self) = @_;
 
